# remirepo/Fedora spec file for php-laminas-hydrator3
#
# Copyright (c) 2016-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

# TODO: v2 pulled by php-ocramius-generated-hydrator
#          pulled by php-ocramius-proxy-manager

%bcond_without       tests

%global gh_commit    de6da92da20873d569532adec94afa7285f21157
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     laminas
%global gh_project   laminas-hydrator
%global php_home     %{_datadir}/php
%global namespace    Laminas
%global library      Hydrator
%global major        4

Name:           php-%{gh_project}%{major}
Version:        4.13.0
Release:        1%{?dist}
Summary:        %{namespace} Framework %{library} component version %{major}

License:        BSD-3-Clause
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        %{gh_commit}/%{name}-%{version}-%{gh_short}.tgz
Source1:        makesrc.sh

BuildArch:      noarch
# Tests
%if %{with tests}
BuildRequires:  php(language) >= 8.0
BuildRequires:  php-date
BuildRequires:  php-reflection
BuildRequires:  php-spl
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-autoloader(%{gh_owner}/laminas-stdlib)               >= 3.3    with php-autoloader(%{gh_owner}/laminas-stdlib)               < 4)
BuildRequires: (php-composer(webmozart/assert)                           >= 1.10   with php-composer(webmozart/assert)                     < 2)
# From composer, "require-dev": {
#        "laminas/laminas-coding-standard": "~2.5.0",
#        "laminas/laminas-eventmanager": "^3.10",
#        "laminas/laminas-modulemanager": "^2.14",
#        "laminas/laminas-serializer": "^2.14",
#        "laminas/laminas-servicemanager": "^3.20",
#        "phpbench/phpbench": "^1.2.8",
#        "phpunit/phpunit": "^9.5.28",
#        "psalm/plugin-phpunit": "^0.18.4",
#        "vimeo/psalm": "^5.6"
BuildRequires: (php-autoloader(%{gh_owner}/laminas-eventmanager)         >= 3.10  with php-autoloader(%{gh_owner}/laminas-eventmanager)         < 4)
BuildRequires: (php-autoloader(%{gh_owner}/laminas-modulemanager)        >= 2.14  with php-autoloader(%{gh_owner}/laminas-modulemanager)        < 3)
BuildRequires: (php-autoloader(%{gh_owner}/laminas-serializer)           >= 2.14  with php-autoloader(%{gh_owner}/laminas-serializer)           < 3)
BuildRequires: (php-autoloader(%{gh_owner}/laminas-servicemanager)       >= 3.20  with php-autoloader(%{gh_owner}/laminas-servicemanager)       < 4)
# remirepo:8
%else
BuildRequires:  php-laminas-stdlib
BuildRequires:  php-webmozart-assert
BuildRequires:  php-laminas-eventmanager
BuildRequires:  php-laminas-modulemanager
BuildRequires:  php-laminas-serializer
BuildRequires:  php-laminas-servicemanager
%endif
%global phpunit %{_bindir}/phpunit9
BuildRequires:  phpunit9 >= 9.5.26
%endif
# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer, "require": {
#        "php": "~8.0.0 || ~8.1.0 || ~8.2.0",
#        "laminas/laminas-stdlib": "^3.3",
#        "webmozart/assert": "^1.10"
Requires:       php(language) >= 8.0
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:      (php-autoloader(%{gh_owner}/laminas-stdlib)               >= 3.3    with php-autoloader(%{gh_owner}/laminas-stdlib)         < 4)
Requires:      (php-composer(webmozart/assert)                           >= 1.10   with php-composer(webmozart/assert)                     < 2)
# From composer, "suggest": {
#        "laminas/laminas-eventmanager": "^3.2, to support aggregate hydrator usage",
#        "laminas/laminas-serializer": "^2.9, to use the SerializableStrategy",
#        "laminas/laminas-servicemanager": "^3.14, to support hydrator plugin manager usage"
Suggests:       php-autoloader(%{gh_owner}/laminas-eventmanager)   >= 3.2
Suggests:       php-autoloader(%{gh_owner}/laminas-serializer)     >= 2.9
Suggests:       php-autoloader(%{gh_owner}/laminas-servicemanager) >= 3.3
# remirepo:4
%else
Requires:       php-laminas-stdlib
Requires:       php-webmozart-assert
%endif
# Autoloader
Requires:       php-composer(fedora/autoloader)
# From phpcompatinfo report for version 2.4.2
Requires:       php-reflection
Requires:       php-pcre
Requires:       php-spl

Provides:       php-composer(%{gh_owner}/%{gh_project})   = %{version}
Provides:       php-autoloader(%{gh_owner}/%{gh_project}) = %{version}


%description
%{namespace}\Hydrator provides utilities for mapping arrays to objects,
and vice versa, including facilities for filtering which data
is mapped as well as providing mechanisms for mapping nested
structures.

Documentation: https://docs.laminas.dev/%{gh_project}/


%prep
%setup -q -n %{gh_project}-%{gh_commit}

mv LICENSE.md LICENSE


%build
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/%{namespace}/Stdlib/autoload.php',
]);
\Fedora\Autoloader\Dependencies::optional([
    '%{php_home}/%{namespace}/ServiceManager/autoload.php',
    '%{php_home}/%{namespace}/EventManager/autoload.php',
    '%{php_home}/%{namespace}/Serializer/autoload.php',
]);
EOF


%install
: Laminas library
mkdir -p   %{buildroot}%{php_home}/%{namespace}/
cp -pr src %{buildroot}%{php_home}/%{namespace}/%{library}%{major}


%check
%if %{with tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require_once '%{buildroot}%{php_home}/%{namespace}/%{library}%{major}/autoload.php';
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/%{namespace}/ModuleManager/autoload.php',
]);
\Fedora\Autoloader\Autoload::addPsr4('%{namespace}Test\\%{library}\\', dirname(__DIR__) . '/test');
\Fedora\Autoloader\Autoload::addPsr4('%{namespace}Bench\\%{library}\\', dirname(__DIR__) . '/benchmark');
EOF

: upstream test suite
ret=0
for cmdarg in "php %{phpunit}" php80 php81 php82; do
  if which $cmdarg; then
    set $cmdarg
    $1 ${2:-%{_bindir}/phpunit9} -d memory_limit=1G || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
# remirepo:1
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{php_home}/%{namespace}/%{library}%{major}


%changelog
* Mon Mar 20 2023 Remi Collet <remi@remirepo.net> - 4.13.0-1
- update to 4.13.0

* Wed Dec 21 2022 Remi Collet <remi@remirepo.net> - 4.12.0-1
- update to 4.12.0

* Wed Dec 14 2022 Remi Collet <remi@remirepo.net> - 4.11.0-1
- update to 4.11.0

* Tue Dec  6 2022 Remi Collet <remi@remirepo.net> - 4.10.0-1
- update to 4.10.0

* Mon Dec  5 2022 Remi Collet <remi@remirepo.net> - 4.9.0-1
- update to 4.9.0

* Tue Oct 25 2022 Remi Collet <remi@remirepo.net> - 4.8.0-1
- update to 4.8.0

* Mon Oct 17 2022 Remi Collet <remi@remirepo.net> - 4.7.0-1
- update to 4.7.0

* Fri Oct 14 2022 Remi Collet <remi@remirepo.net> - 4.6.0-1
- update to 4.6.0
- raise dependency on PHP 8.0

* Thu Jul 14 2022 Remi Collet <remi@remirepo.net> - 4.5.0-1
- update to 4.5.0

* Wed Jul 13 2022 Remi Collet <remi@remirepo.net> - 4.4.0-1
- update to 4.4.0
- raise dependency on PHP 7.4

* Thu Jan  6 2022 Remi Collet <remi@remirepo.net> - 4.3.1-1
- update to 4.3.1
- rename to php-laminas-hydrator4
- install in /usr/share/php/Laminas/Hydrator4
- add dependency on webmozart/assert
- drop ZF compatibility layer

* Tue Jun 29 2021 Remi Collet <remi@remirepo.net> - 3.2.1-1
- update to 3.2.1

* Wed Feb 24 2021 Remi Collet <remi@remirepo.net> - 3.2.0-1
- update to 3.2.0
- raise dependency on PHP 7.3
- raise dependency on laminas-stdlib 3.3
- switch to phpunit9

* Mon Jan 20 2020 Remi Collet <remi@remirepo.net> - 3.0.2-1
- update to 3.0.2
- rename to php-laminas-hydrator3
- install in /usr/share/php/Zend/Hydrator3
- raise dependency on PHP 7.2
- raise dependency on laminas-stdlib 3.2.1

* Fri Jan 10 2020 Remi Collet <remi@remirepo.net> - 2.4.2-1
- switch to Laminas

* Thu Jan  2 2020 Remi Collet <remi@remirepo.net> - 2.4.2-1
- update to 2.4.2

* Thu Nov 22 2018 Remi Collet <remi@remirepo.net> - 2.4.1-1
- update to 2.4.1

* Thu May  3 2018 Remi Collet <remi@remirepo.net> - 2.4.0-1
- update to 2.4.0
- use range dependencies on F27+
- switch to phpunit6 or phpunit7

* Thu Dec  7 2017 Remi Collet <remi@remirepo.net> - 2.3.1-2
- switch from zend-loader to fedora/autoloader

* Tue Oct  3 2017 Remi Collet <remi@remirepo.net> - 2.3.1-1
- Update to 2.3.1

* Thu Sep 21 2017 Remi Collet <remi@remirepo.net> - 2.3.0-1
- Update to 2.3.0

* Thu Sep 21 2017 Remi Collet <remi@remirepo.net> - 2.2.3-1
- Update to 2.2.3

* Mon May 22 2017 Remi Collet <remi@remirepo.net> - 2.2.2-1
- Update to 2.2.2
- raise dependency on PHP 5.6
- use phpunit6 on F26+

* Wed Jun 29 2016 Remi Collet <remi@fedoraproject.org> - 2.2.1-1
- update to 2.2.1 for ZendFramework 3
- raise dependency on zend-stdlib >= 3.0

* Fri Feb 19 2016 Remi Collet <remi@fedoraproject.org> - 1.1.0-1
- update to 1.1.0
- raise dependency on zend-stdlib >= 2.7

* Thu Jan 28 2016 Remi Collet <remi@fedoraproject.org> - 1.0.1-1
- initial package
